summaryrefslogtreecommitdiff
path: root/ace/Local_Name_Space_T.h
diff options
context:
space:
mode:
authorirfan <irfan@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1997-02-01 10:01:52 +0000
committerirfan <irfan@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1997-02-01 10:01:52 +0000
commitfa588f6bab7b72f0d6d49d7f5e6eff46eb04ebbb (patch)
tree6a146bd561aec0da75a9630185619a99dbd4b065 /ace/Local_Name_Space_T.h
parenteda7bc28bba8d4649e95d489e50832ba2cc1e723 (diff)
downloadATCD-fa588f6bab7b72f0d6d49d7f5e6eff46eb04ebbb.tar.gz
*** empty log message ***
Diffstat (limited to 'ace/Local_Name_Space_T.h')
-rw-r--r--ace/Local_Name_Space_T.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/ace/Local_Name_Space_T.h b/ace/Local_Name_Space_T.h
index 616019884a9..e223721be91 100644
--- a/ace/Local_Name_Space_T.h
+++ b/ace/Local_Name_Space_T.h
@@ -21,6 +21,7 @@
#if !defined (ACE_LOCAL_NAME_SPACE_T_H)
#define ACE_LOCAL_NAME_SPACE_T_H
+#include "ace/Hash_Map_Manager.h"
#include "ace/Name_Space.h"
#include "ace/Naming_Context.h"
#include "ace/SString.h"
@@ -31,9 +32,9 @@
typedef ACE_Unbounded_Set<ACE_WString> ACE_WSTRING_SET;
// Simplify later usage by defining typedefs.
-typedef ACE_Map_Manager<ACE_NS_String, ACE_NS_Internal, ACE_Null_Mutex> MAP_MANAGER;
-typedef ACE_Map_Iterator<ACE_NS_String, ACE_NS_Internal, ACE_Null_Mutex> MAP_ITERATOR;
-typedef ACE_Map_Entry <ACE_NS_String, ACE_NS_Internal> MAP_ENTRY;
+typedef ACE_Hash_Map_Manager<ACE_NS_String, ACE_NS_Internal, ACE_Null_Mutex> MAP_MANAGER;
+typedef ACE_Hash_Map_Iterator<ACE_NS_String, ACE_NS_Internal, ACE_Null_Mutex> MAP_ITERATOR;
+typedef ACE_Hash_Map_Entry <ACE_NS_String, ACE_NS_Internal> MAP_ENTRY;
template <class ALLOCATOR>
class ACE_Name_Space_Map : public MAP_MANAGER
@@ -55,7 +56,7 @@ public:
// Constructor.
// = The following methods are Proxies to the underlying methods
// provided by <ACE_Map_Manager>. When they are called, they
// acquire the lock, set the allocator to the one specific to this
// process, and then call down to perform the intended operation.
int bind (const ACE_NS_String &,
@@ -55,7 +56,7 @@ public:
// Constructor.
// = The following methods are Proxies to the underlying methods
- // provided by <ACE_Map_Manager>. When they are called, they
+ // provided by <ACE_Hash_Map_Manager>. When they are called, they
// acquire the lock, set the allocator to the one specific to this
// process, and then call down to perform the intended operation.